import functools
from flask import Blueprint, abort
from app import login_manager
from ..models import User
from flask_login import current_user

auth = Blueprint('auth',
                 __name__,
                 template_folder='./../templates/auth',
                 static_folder='static'
                 )


def authenticate(username, password):
    user = User.query.filter_by(username=username).first()
    if not user:
        return None
    if not user.verify_password(password):
        return None
    return user


def identity(payload):
    return load_user(payload['identity'])


def has_role(name):
    def real_decorator(f):
        def wraps(*args, **kwargs):
            if current_user.has_role(name):
                return f(*args, **kwargs)
            else:
                abort(403)
        return functools.update_wrapper(wraps, f)
    return real_decorator


@login_manager.user_loader
def load_user(userid):
    return User.query.get(userid)


from . import views
